@@ -215,7 +215,7 @@ class SubProcessIngestionTask(Task):
                 with open(report_out_file,'r') as structured_report_fp:
                     ctx.get_report().set_structured_report(structured_report_fp.read())
 
-            ctx.get_report().report_info(f"stdout={SubProcessTaskUtil._format_log_lines(stdout_lines)}")
+            ctx.get_report().report_info(f"stdout={SubProcessTaskUtil._format_log_lines(stdout_lines)}", log=False)
             
             # Cleanup by removing the recipe file
             SubProcessTaskUtil._remove_directory(exec_out_dir)
