@@ -54,14 +54,16 @@ class ExecutionReport(Report):
         self.infos = []
         self.errors = []
 
-    def report_info(self, message: str) -> None:
+    def report_info(self, message: str, log=True) -> None:
         formatted_message = self._format_report_line("INFO", message)
-        print(formatted_message) # TODO: Add flag for printing to STDOUT
+        if log:
+            print(formatted_message)
         self.infos.append(formatted_message)
 
-    def report_error(self, message: str) -> None:
+    def report_error(self, message: str, log=True) -> None:
         formatted_message = self._format_report_line("ERROR", message)
-        print(formatted_message) # TODO: Add flag for printing to STDOUT
+        if log:
+            print(formatted_message)
         self.errors.append(formatted_message)
 
     def set_structured_report(self, report_content: str) -> None:
